from .preprocessing import  dtypes_df, change_type, columns_names, outlier_filter, quant_to_cat, transform_to_dummies,  count_cols_nulls, prop_cols_nulls, count_row_nulls, prop_row_nulls, all_null_colum, too_much_nulls_colums, null_imputation
from .descriptive import weighted_mean, inv_quantile, kurtosis, skewness, MAD, outlier_detection, outliers_table, freq_table, summary, cross_quant_cat_summary, contingency_table_2D, contingency_table_3D, cov_matrix, corr_matrix, high_corr 
from .plots import histogram, histogram_matrix, boxplot, boxplot_matrix, ecdfplot, ecdfplot_matrix, barplot, barplot_matrix, scatterplot, scatterplot_matrix, stripplot, stripplot_matrix, boxplot_2D, boxplot_2D_matrix, histogram_2D, histogram_2D_matrix, ecdfplot_2D, ecdfplot_2D_matrix, barplot_2D



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="BigEDA",
    version="0.0.9",
    author="Fabio Scielzo Ortiz",
    author_email="fabioscielzo98@gmail.com",
    description="This is a package to carry out Exploratory Data Analysis, allowing to work with Big Data.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/FabioScielzoOrtiz/EDA_Package",  # add your project URL here
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=['pandas','numpy', 'polars', 'scipy', 'itertools', 
                      'collections', 'seaborn', 'matplotlib', 'random'],
    python_requires=">=3.7"
)
